@@ -1069,6 +1069,7 @@ void xls_xml_context::start_element_border(const xml_token_pair_t& parent, const
 
     spreadsheet::border_direction_t dir = spreadsheet::border_direction_t::unknown;
     spreadsheet::border_style_t style = spreadsheet::border_style_t::unknown;
+    spreadsheet::color_rgb_t color;
     long weight = 0;
 
     for (const xml_token_attr_t& attr : attrs)
@@ -1093,6 +1094,11 @@ void xls_xml_context::start_element_border(const xml_token_pair_t& parent, const
                 weight = to_long(attr.value);
                 break;
             }
+            case XML_Color:
+            {
+                color = spreadsheet::to_color_rgb(attr.value.data(), attr.value.size());
+                break;
+            }
             default:
                 ;
         }
@@ -1105,6 +1111,7 @@ void xls_xml_context::start_element_border(const xml_token_pair_t& parent, const
     border_style_type& bs = m_current_style->borders.back();
     bs.dir = dir;
     bs.style = style;
+    bs.color = color;
 
     switch (bs.style)
     {
@@ -1215,6 +1222,7 @@ void xls_xml_context::start_element_column(const xml_token_pair_t& parent, const
     spreadsheet::col_t col_index = m_cur_prop_col;
     spreadsheet::col_t span = 0;
     double width = 0.0;
+    bool hidden = false;
 
     std::for_each(attrs.begin(), attrs.end(),
         [&](const xml_token_attr_t& attr)
@@ -1237,6 +1245,8 @@ void xls_xml_context::start_element_column(const xml_token_pair_t& parent, const
                 case XML_Span:
                     span = to_long(attr.value);
                     break;
+                case XML_Hidden:
+                    hidden = to_long(attr.value) != 0;
                 default:
                     ;
             }
@@ -1244,8 +1254,11 @@ void xls_xml_context::start_element_column(const xml_token_pair_t& parent, const
     );
 
     for (; span >= 0; --span, ++col_index)
+    {
         // Column widths are stored as points.
         mp_sheet_props->set_column_width(col_index, width, orcus::length_unit_t::point);
+        mp_sheet_props->set_column_hidden(col_index, hidden);
+    }
 
     m_cur_prop_col = col_index;
 }
@@ -1256,6 +1269,7 @@ void xls_xml_context::start_element_row(const xml_token_pair_t& parent, const xm
     m_cur_col = 0;
     spreadsheet::row_t row_index = -1;
     bool has_height = false;
+    bool hidden = false;
     double height = 0.0;
 
     for (const xml_token_attr_t& attr : attrs)
@@ -1274,6 +1288,9 @@ void xls_xml_context::start_element_row(const xml_token_pair_t& parent, const xm
                     has_height = true;
                     height = to_double(attr.value);
                     break;
+                case XML_Hidden:
+                    hidden = to_long(attr.value) != 0;
+                    break;
                 default:
                     ;
             }
@@ -1286,8 +1303,14 @@ void xls_xml_context::start_element_row(const xml_token_pair_t& parent, const xm
         m_cur_row = row_index - 1;
     }
 
-    if (mp_sheet_props && has_height)
-        mp_sheet_props->set_row_height(m_cur_row, height, length_unit_t::point);
+    if (mp_sheet_props)
+    {
+        if (has_height)
+            mp_sheet_props->set_row_height(m_cur_row, height, length_unit_t::point);
+
+        if (hidden)
+            mp_sheet_props->set_row_hidden(m_cur_row, true);
+    }
 }
 
 void xls_xml_context::end_element_borders()
@@ -1311,7 +1334,7 @@ void xls_xml_context::end_element_cell()
         mp_sheet_props->set_merge_cell_range(merge_range);
     }
 
-    if (!m_cur_cell_style_id.empty())
+    if (mp_cur_sheet && !m_cur_cell_style_id.empty())
     {
         auto it = m_style_map.find(m_cur_cell_style_id);
         if (it != m_style_map.end())
@@ -1321,6 +1344,16 @@ void xls_xml_context::end_element_cell()
         }
     }
 
+    if (mp_cur_sheet && !m_cur_cell_formula.empty())
+    {
+        // Likely a Cell element without a child Data element.
+        mp_cur_sheet->set_formula(
+            m_cur_row, m_cur_col, spreadsheet::formula_grammar_t::xls_xml,
+            m_cur_cell_formula.data(), m_cur_cell_formula.size());
+    }
+
+    m_cur_cell_formula.clear();
+
     ++m_cur_col;
     if (m_cur_merge_across > 0)
         m_cur_col += m_cur_merge_across;
@@ -1525,7 +1558,10 @@ void xls_xml_context::commit_styles()
             styles->set_border_count(style->borders.size());
 
             for (const border_style_type& b : style->borders)
+            {
                 styles->set_border_style(b.dir, b.style);
+                styles->set_border_color(b.dir, 255, b.color.red, b.color.green, b.color.blue);
+            }
 
             size_t border_id = styles->commit_border();
             styles->set_xf_border(border_id);
